@@ -109,6 +109,10 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(days=-29)).strftime("%Y-%m-%d")
         end_date = today.strftime("%Y-%m-%d 23:59:59")
 
+    elif period_config == "l365d":
+        start_date = (today + relativedelta(days=-364)).strftime("%Y-%m-%d")
+        end_date = today.strftime("%Y-%m-%d 23:59:59")
+
     elif period_config == "l45d":
         start_date = (today + relativedelta(days=-44)).strftime("%Y-%m-%d")
         end_date = today.strftime("%Y-%m-%d")
@@ -597,7 +601,7 @@ class DataSource:
         ORDER BY character_maximum_length DESC;
 
         ''' % params
-        result = {'table_name': '%(schema_name)s.%(table_name)s' % params,
+        result = {'base_table_name': '%(schema_name)s.%(table_name)s' % params,
                   'partition_by': None, 'order_by': None,
                   'columns': self.dbstream.execute_query(query)}
         file_name = self.path_to_datasource_folder + '/layers/' + layer + '/prep_configs/' + schema_name + '_' + table_name + '.yaml'
